
[![Tests](https://github.com/hyperspy/holospy/actions/workflows/tests.yml/badge.svg)](https://github.com/hyperspy/holospy/actions/workflows/tests.yml)
[![codecov](https://codecov.io/gh/hyperspy/holospy/graph/badge.svg?token=XB1QDTXQ86)](https://codecov.io/gh/hyperspy/holospy)
[![Docs](https://readthedocs.org/projects/holospy/badge/?version=latest)](https://holospy.readthedocs.io/en/latest/?badge=latest)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![DOI](https://zenodo.org/badge/2233998.svg)](https://zenodo.org/badge/latestdoi/2233998)

**HoloSpy** is a Python package extending the functionality for multi-dimensional
data analysis provided by the [HyperSpy](https://hyperspy.org) library. It is
aimed at helping with the analysis of (off-axis) electron holography data.

Go to the documentation for instructions on how to install HoloSpy and start an
analysis: [Read the docs](https://holospy.readthedocs.io).

Everyone is welcome to contribute. Please read our
[contributing guidelines](https://github.com/hyperspy/holospy/blob/main/CONTRIBUTING.rst) and get started!

Development of HoloSpy is documented in the
[changelog](https://github.com/hyperspy/holospy/blob/main/CHANGES.rst).
